// Calculate the diffusion coefficient of a particle.
// D0 = < r^2> / 6 t
// 
// Columns in the input are (reading stdin):    time  x  y  z
// 
// compile with:  gcc -o D0 D0.c 
// 
// This file is part of the brownmove tutorials
// Tihamer Geyer, 2009

#include <stdio.h>
#include <math.h>


int main() {
	double xn, yn, zn, tn;
	double xa, ya, za, ta;
	double sx, sy, sz;
	long int anzahl = 0;
	double dt;
	
	sx = sy = sz = 0.0;

	// read first line, initialize old positions
	if(fscanf(stdin, "%lf %lf %lf %lf\n", &ta, &xa, &ya, &za) != 4) {
		return(-3);
	}

	// read the rest until EOF, goes into new positions
	while(1==1) {
		if(fscanf(stdin, "%lf %lf %lf %lf\n", &tn, &xn, &yn, &zn) != 4) {
			break;
		}

		// determine distances during last timestep...
		double dx = xn - xa;
		double dy = yn - ya;
		double dz = zn - za;
		dt = tn - ta;
		
		// ... and sum up the squares
		sx += dx*dx;
		sy += dy*dy;
		sz += dz*dz;
		anzahl++;
		
		// current positions -> old positions
		xa = xn;
		ya = yn;
		za = zn;
		ta = tn;
	}
	
	// done, determine individual diffusion coeffs 
	double durch = (2.0 * (double)anzahl * dt);
	sx /= durch;
	sy /= durch;
	sz /= durch;
	
	// tell the result
	printf("dt = %lf    D0 = %e   Di = %e, %e, %e\n", dt, (sx+sy+sz)/3.0, sx, sy, sz);
	
	return(0);
}
