# Compresses the brownmove output from a polymer simulation
# to position of the CM and the vector from the first to the last bead
# 
# This file is part of the brownmove tutorials
# Tihamer Geyer, 2009

use strict;

# need some variables
my $isTimeLine = 1;
my $zeitPunkt;
my $anzProt;

# for the CM
my $sumx;
my $sumy;
my $sumz;

# positions of the first and last bead, resp
my $x1; my $y1; my $z1;
my $xN; my $yN; my $zN;

# number of beads (lines)
my $zeilen;

# un-buffer output
select(STDOUT); $| = 1;

# read 
while(<STDIN>)
{
	split(' ');

	# is this a "timeline"?
	if($isTimeLine == 1)
	{
		$zeitPunkt = $_[1];
		$anzProt = $_[2];
		$zeilen = $anzProt;
		
		$isTimeLine = 0 if ($anzProt > 0);
	} 
	else 
	{
		# extract relevant data
		my $label = $_[0];
		my $num = $_[1];
		my $x = $_[3];
		my $y = $_[4];
		my $z = $_[5];

		# sum up for CM (assume all masses are equal)
		$sumx += $x;
		$sumy += $y;
		$sumz += $z;
		
		# save first Bead 
		if($anzProt == $zeilen) {
			$x1 = $x; $y1 = $y; $z1 = $z;
		} 
		
		# save last bead
		if($anzProt == 1) {
			$xN = $x; $yN = $y; $zN = $z;
		}
		
		# count down
		$anzProt--;	
		# until all bead lines are read
		if ($anzProt == 0)
		{
			$isTimeLine = 1 ;
			
			# do the normalization
			$sumx = $sumx / $zeilen;
			$sumy = $sumy / $zeilen;
			$sumz = $sumz / $zeilen;
			my $dx = $xN - $x1;
			my $dy = $yN - $y1;
			my $dz = $zN - $z1;
			# and print compressed data
			print "$zeitPunkt\t$sumx\t$sumy\t$sumz\t$dx\t$dy\t$dz\n";
			
			# some more resets
			$sumx = 0.0; $sumy = 0.0; $sumz = 0.0;
		}
	}
}

exit;
