// This file is part of the brownmove simulation package
// 
// V1.1  Oct 2010
// 
// (C) 2003 - 2010 Tihamer Geyer
// tihamer.geyer@bioinformatik.uni-saarland.de
// 
// Check for Updates at the Project Homepage 
// http://service.bioinformatik.uni-saarland.de/brownmove



#ifndef CONSTANTS_H
#define CONSTANTS_H


// This file contains some definitions of global constants

//! @name Internal units (for conversions):
//! @{

//! time: 1 ps = 10^-12 s
const double PICO = 1e-12;
//! distance: 1 nm = 1e-9 m
const double NANO  = 1.0e-9;

//! mass: 1 kDa = 1e3 m_proton = 1.67262e-21 g
const double KDALTON	= 1.67262e-21;

//! energy: 1 kJ/mol = 9.9278e-4 kDa nm^2/ps^2
const double KJOULEMOL = 9.9278e-4;
//! @}


//! @name Physical constants
//! @{
// Viscosity of water ETA_0 = 0.89e-3 kg/(m*s) = 0.532 kDa/(nm ps)
// const double ETA_0 = 0.532;

//! Boltzmann-Constant k_B = 1.3807e-23 J/K = 8.3145e-3 kJ/(mol K)
const double K_B  = 8.3145e-3;

//! dielectric constant of the vacuum eps_0 = 8.8542e-12 As/Vm = 5.7276e-4 e^2/(kJ/mol nm)
const double EPS_0 = 5.7276e-4;
//! @}

#endif /* CONSTANTS_H */
