// This file is part of the brownmove simulation package
// 
// V1.1  Oct 2010
// 
// (C) 2003 - 2010 Tihamer Geyer
// tihamer.geyer@bioinformatik.uni-saarland.de
// 
// Check for Updates at the Project Homepage 
// http://service.bioinformatik.uni-saarland.de/brownmove



#ifndef MOLECULEHANDLER_H
#define MOLECULEHANDLER_H

#include <string>

#include "molecule.h"
#include "cup.h"

namespace brown {
	/** Parent class for molecule acceptor and injector
	 *
	 * @author tg
	 */
	class MoleculeHandler {
		public:
		//! Default constructor with a label
		MoleculeHandler(string label);
		//! Copy constructro
		MoleculeHandler(const MoleculeHandler &other);
		//! Destructor
		~MoleculeHandler() {};
		
		/** set the coordinate system pointers */
		void setCoordSystem(position *p, direction *n, direction *y, direction *z) {
			myWallsPosition = p;
			myWallsNormal = n;
			myWallsYAxis  = y;
			myWallsZAxis  = z;
		}

		
		//! set the cup containing the wall containing this mol.-handler
		void setCup(Cup *theC) {
			myWallsCup = theC;
		}
		
		/* 
		 * void describe() {
		 *     cout 
		 *     cout << "    MoleculeHandler::describe: myWallsCup = " << myWallsCup << endl;
		 *     cout << "    MoleculeHandler::describe: myWallsPos = " << myWallsPosition << endl;
		 *     cout << "    MoleculeHandler::describe: wallpos =    " << (*myWallsPosition)[0]<<" "<<(*myWallsPosition)[1]<<" "<<(*myWallsPosition)[2]<< endl;
		 * }
		 */
		
		//! Return a descriptive string
		std::string describe() { return(std::string("")); };
		
		//! set the label
		void setLabel(string &newLabel) {
			label = newLabel;
		}
		
		//! get the label
		const string &getLabel () {
			return label;
		}
		
		
		//! Set a rectangular mask for inserting particles.
		//! The mask extends (y0 +- dY, z0 +- dZ).
		void setRectangleMask(const double y0, const double z0, const double dy, const double dz) {
			maskY0 = y0; maskZ0 = z0; maskdY = dy; maskdZ = dz; 
			maskArea = 4.0 * dy * dz;
		}

			
		protected:
		//! @name Pointers to the wall's position and coordinate system 
		//! to be used for defining insertion/take out regions on the wall
		// @{
		position  *myWallsPosition;
		direction *myWallsNormal;
		direction *myWallsYAxis;
		direction *myWallsZAxis;
		// @}
		
		//! pointer to the cup containing the wall
		Cup *myWallsCup;
		//! label, used for identifying where a molecule was inserted
		string label;
		//! a rectangular mask
		double maskY0, maskZ0, maskdY, maskdZ, maskArea;
	};
}



#endif /* MOLECULEHANDLER_H */
