// This file is part of the brownmove simulation package
// 
// V1.1  Oct 2010
// 
// (C) 2003 - 2010 Tihamer Geyer
// tihamer.geyer@bioinformatik.uni-saarland.de
// 
// Check for Updates at the Project Homepage 
// http://service.bioinformatik.uni-saarland.de/brownmove



#ifndef MOLECULEINJECTOR_H
#define MOLECULEINJECTOR_H

#include <vector>
#include <map>
#include <gsl/gsl_rng.h>
#include <time.h>
#include <math.h>

#include "molecule.h"
#include "moleculehandler.h"
#include "cup.h"

#include "vectormath.h"
#include "random.h"
#include "erfcc.h"
#include "types.h"

namespace brown{
	/** An interface to insert molecules above a wall. These can come from a
	 *  constant density reservoir or a diffusion grid (which is not implemented yet)
	 *
	 * @author tg  
	 */ 
	class MoleculeInjector : public MoleculeHandler {
		public: 
		//! Default Constructor with a label
		MoleculeInjector(string newLabel);
		//! Copy constructor
		MoleculeInjector(MoleculeInjector &other);
		//! Destructor
		~MoleculeInjector(){};
		
		//! Let me introduce myself...
		std::string describe();
		

		//! set the pointer to the mask function 
		// void setMask(injectPtr &ap) {
		// 	myMask = ap;
		// }
		
		
		//! struct containing the template molecules, their concentrations to be inserted
		//! and the inverse volume of the reservoir.
		//! If the pointer to the vector<fullPosition> is set, these positions will be used for
		//! inserting the new molecules -- makes sense only with a negative invVol.
		struct insertTemplate {
			std::string molName;
			std::string resName;
			Molecule *mol;
			double *concentration;
			double invVol;
			vector<fullPosition> *insPos;
			int *theInternal;
			int resInc;
			long int immobilizeT;
		};
		
		//! Add another molecule species to be inserted: 
		//! ref/pointer to template molecule and (pointer to) concentration
		void addMolecule(Molecule &oldMol, double *concentration, const double &invVol, vector<fullPosition> *insPos, int *theInternal, int resCond, long int immobilizeT);
		//! Parser-induced version with labels for molecule and reservoir to be filled in later in resolveMolName()
		void addMolecule(std::string molName, std::string resName);
		
		//! Resolve the names of the molecules and get the corresponding molecules from the parser's map of molecules. Called from cup when wall is inserted into the cup.
		void resolveMolNames(std::map<std::string, Molecule*> *molMap);
		
		//! Resolve the names of the reservoirs. Called from cup when wall is inserted into the cup.
		void resolveResNames(std::map<std::string, struct reservoir> *resMap);
		
		//! Insert molecules according to the template(s)
		void insert();
		
		
		private:
		static gsl_rng *rng;
		// injectPtr myMask;
		//! vector of template molecules and pointers to their resp. concentrations
		vector<insertTemplate> molTemplates;
	};
}
#endif /* MOLECULEINJECTOR_H */
