// This file is part of the brownmove simulation package
// 
// V1.1  Oct 2010
// 
// (C) 2003 - 2010 Tihamer Geyer
// tihamer.geyer@bioinformatik.uni-saarland.de
// 
// Check for Updates at the Project Homepage 
// http://service.bioinformatik.uni-saarland.de/brownmove



#ifndef PROTEINPARSER_H
#define PROTEINPARSER_H

#include <stdio.h>
#include <list>
#include <string>
#include <map>
#include <stdlib.h>
#include <string.h>

#include "geomshape.h"
#include "vdwshape.h"
#include "molecule.h"
#include "gestalt.h"
#include "cup.h"
#include "molecule.h"
#include "estatshape.h"
#include "hishape.h"
#include "externalshape.h"
#include "markershape.h"
#include "interactingBody.h"
#include "wall.h"
#include "moleculeinjector.h"
#include "moleculeacceptor.h"

#include "constants.h"
#include "globalstuff.h"

namespace brown {
	
	//! @author tg
	//
	//! Parses the protein setup files and sets up molecules or walls (interacting bodies)
	class ProteinParser {
		public:
		//! Simple constructor, not much to initialize
		ProteinParser(double &dt) {
			timeStep = dt;
		};
		//Destructor
		~ProteinParser() {};
		
		//! Parse the given setup file, choose protein number entry_num
		//! Returns false if anything failed during the parsing or setup
		//! Detailed error information is dumped to stderr
		bool parse(InteractingBody* ib, const char *filename, const int entry_num, const long int maxVdwColor, list<externalForce> &felder, parserContext context, std::map<std::string, std::string> *constants, std::list<std::string> *fileList);
		
		
		private:
		//! State of the parser: at which level are we currently parsing /assembling
		enum parserlevels {
			OuterL, ProteinL, BondsL, GestaltL, EstatShapeL, vdWShapeL, HBondShapeL, BondShapeL, HiShapeL, ExtShapeL, MarkerShapeL,
			InjectorL, AcceptorL, MarkerL };
			
		//! Type of interacting body that we're parsing
		enum bodyTypes { ProteinT, WallT, ObstacleT };
		
		//! Chop off the first two words from the input
		//! If there is only one word in newLine, tag2 = ""
		int firstWords(const char *newLine, char *tag, char *tag2);
		
		//! Local copy of the simulation timestep, required by the molecules to initialize stepsizes, damping etc
		double timeStep;
	};
}

#endif

