// This file is part of the brownmove simulation package
// 
// V1.1  Oct 2010
// 
// (C) 2003 - 2010 Tihamer Geyer
// tihamer.geyer@bioinformatik.uni-saarland.de
// 
// Check for Updates at the Project Homepage 
// http://service.bioinformatik.uni-saarland.de/brownmove



#include "markershape.h"

namespace brown{

	MarkerShape::MarkerShape(const MarkerShape &other){
		markers = other.markers;
		actual_markers = other.actual_markers;
	}
	
	MarkerShape::~MarkerShape(){
		markers.clear();
		actual_markers.clear();
	}
	
	
	std::string MarkerShape::describe(){
		ostringstream ausgabe("", ios::out);
		int i=0;
		
		ausgabe << "actual marker positions";
		vector<markerPos>::iterator mlc;
		for(mlc = actual_markers.begin(); mlc != actual_markers.end(); ++mlc, i++){
			ausgabe << " : "<<(*mlc).pos[0]<<" "<<(*mlc).pos[1]<<" "<<(*mlc).pos[2] ; 
		}
		ausgabe <<" :";
		for(mlc = markers.begin(); mlc != markers.end(); ++mlc, i++){
			ausgabe << " : "<<(*mlc).pos[0]<<" "<<(*mlc).pos[1]<<" "<<(*mlc).pos[2] ; 
		}
		return(ausgabe.str());
	}
	
	
	void MarkerShape::recalculate(const fullPosition &p) 
	{
		vector<markerPos>::iterator act = actual_markers.begin();
		for(vector<markerPos>::iterator mlc = markers.begin(); mlc != markers.end(); ++mlc, ++act)
		{
			doublevec_set((*act).pos, (*mlc).pos);
			doublevec_rotate((*act).pos, p.rot);
			positionMove((*act).pos, p.pos);
			doublevec_set((*act).dr, (*act).pos);
			doublevec_sub((*act).dr, p.pos);
		}
	}
	
	
	void MarkerShape::addMarker(markerPos cp, const position &moleculeCenter){
		doublevec_set(cp.dr, cp.pos);
		doublevec_sub(cp.dr, moleculeCenter);
		markers.push_back(cp);
		actual_markers.push_back(cp);
	}
	
	
	
	void MarkerShape::dumpStructure() {
		std::cout << "\n\t\tMarkerShape myMarkers" << std::endl;
		
		for(std::vector<markerPos>::iterator it = markers.begin(); it != markers.end(); it++) {
			std::cout << "\t\t\t"<< (*it).pos[0]<<" "<<(*it).pos[1]<<" "<<(*it).pos[2]<<"   "<<(*it).idx<< std::endl;
		}
		
		std::cout << "\t\tEnd" << std::endl;
	}

	
	int MarkerShape::dumpMarkers(char *prefix, std::string *raus) {
		int i = 1;
		ostringstream ausgabe("", ios::out);

		for(std::vector<markerPos>::iterator it = actual_markers.begin(); it != actual_markers.end(); it++, i++) {
			ausgabe << prefix << (*it).idx << " "<< (*it).pos[0]<<" "<<(*it).pos[1]<<" "<<(*it).pos[2] << std::endl;
		}
		
		(*raus) += ausgabe.str();
		return(i-1);
	}
	
}
